location — Pyskool 1.1.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pyskool 1.1.1 documentation »

# location

Defines the `Location` class.

class `location.` `Location`(coords)

  A location in the skool specified by a pair of coordinates.

  Parameters: | coords – The coordinates of this location.

  `coords`()

    Return the coordinates of this location as a 2-tuple.

### Navigation

- index
- modules |
- next |
- previous |
- Pyskool 1.1.1 documentation »